@@ -2,25 +2,35 @@ import json
 from typing import Dict
 from inspect import isclass
 
+__version__ = '0.6.1'
 
 renderers: Dict = {}
 
 
 class BaseNode:
+    """
+    Base Node class with reference implemention for common cases.
+    This should be used as base class for all leaf level nodes which do not contain
+    other nodes.
+    """
     type = "prose-mirror_content-type"
     wrap_tag: str = ""
 
-    def render(self, in_data):
+    def render(self, in_data) -> str:
         out = self.inner_render(in_data)
         if self.wrap_tag:
             return f"<{self.wrap_tag}>{out}</{self.wrap_tag}>"
         return out
 
-    def inner_render(self, node):
-        return node["content"]
+    def inner_render(self, node) -> str:
+        return node["content"]["text"]
 
 
 class BaseContainer(BaseNode):
+    """
+    Base class for container type nodes which may further contain other nodes.
+    """
+
     def inner_render(self, nodes: Dict) -> str:
         out = ""
         for node in nodes.get("content", []):
@@ -69,6 +79,17 @@ class Image(BaseNode):
         return html
 
 
+class Embed(BaseContainer):
+    type = "embed"
+
+    def inner_render(self, node) -> str:
+        attrs = node['attrs']
+        html = attrs.get('html', '')
+        if attrs.get('type') == 'video' and attrs.get('caption').strip():
+            html += f"<figcaption>{attrs['caption']}</figcaption>"
+        return html
+
+
 class Title(BaseContainer):
     type = "title"
     wrap_tag: str = "h1"
@@ -91,6 +112,13 @@ class HardBreak(BaseContainer):
         return "<br>"
 
 
+class HorizontalRule(BaseNode):
+    type = "horizontal_rule"
+
+    def inner_render(self, node):
+        return "<hr>"
+
+
 class ListItem(BaseContainer):
     type = "list_item"
     wrap_tag: str = "li"
